package com.sodius.mdw.core.eval.project;

import java.io.File;
import java.util.Collection;

/**
 * Describes the contents (template, rules & scripts) of a project.
 * 
 * <p>
 * This interface is not intended to be implemented by clients.
 * </p>
 * 
 * @see com.sodius.mdw.core.eval.EvaluationContext#getProject()
 * @see com.sodius.mdw.core.eval.EvaluationManager#loadProject(File)
 */
public interface Project {
    
    /**
     * Returns the project name.
     * 
     * @return the project name.
     */
    public String getName();
    
    /**
     * Returns the file from where this project has been loaded.
     * 
     * @return the project file
     * @see com.sodius.mdw.core.eval.EvaluationManager#loadProject(File)
     */
    public File getFile();
    
    /**
     * Returns the collection of available text templates.
     * 
     * @return a unmodifiable collection of <code>TextTemplate</code> elements.
     * @see TextTemplate
     */
    public Collection getTextTemplates();
    
    /**
     * Returns the collection of available rule sets.
     * 
     * @return a unmodifiable collection of <code>RuleSet</code> elements.
     * @see RuleSet
     */
    public Collection getRuleSets();
    
    /**
     * Returns the collection of available rules with an visibility <code>entry</code>.
     * 
     * @return an unmodifiable collection of <code>Rule</code> elements.
     * @see Rule 
     * @see RuleSet#getRules()
     * @see VisibilityKind#ENTRY_POINT
     */
    public Collection getEntryRules();
    
    /**
     * Returns the collection of types on which at least one script is defined.
     * 
     * @return a unmodifiable collection of <code>Type</code> elements.
     * @see Type
     */
    public Collection getTypes();
    
    /**
     * Returns the collection of root types (with no super-types) on which at least one script is defined.
     * 
     * @return a unmodifiable collection of <code>Type</code> elements.
     * @see Type#isRoot()
     */
    public Collection getRootTypes();
    

}
